import { ObjectId } from 'bson';
import { EveClient } from './eve-client';
import { Dict } from '../types';
import { IMwsCredentials } from './product-pricing-client';
import { AmazonType, ApiBarcode, Environment, MarketplaceName } from '..';
export declare type ProductStatus = 'ok' | 'paused' | 'notFound' | 'error' | 'missingBarcode';
export declare class ProductServiceClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    getPage(companyId: ObjectId, marketplace: MarketplaceName, search: string, sort: any[], skip: number, perPage: number, buyBox?: boolean, isBuyBoxWinner?: boolean, status?: ProductStatus[], hasStock?: boolean, requestStatuses?: boolean): Promise<any>;
    getCount(companyId: ObjectId, marketplace: MarketplaceName, search: string, buyBox?: boolean, isBuyBoxWinner?: boolean, status?: ProductStatus[], hasStock?: boolean): Promise<any>;
    frontendUpdateProductVariant(companyId: ObjectId, variant: ApiVariant): Promise<any>;
    getProductsFromLastUpdated(companyId: ObjectId, lastUpdated: Date): Promise<ApiVariant[]>;
    getAllProducts(companyId: ObjectId, page: number, perPage?: number): Promise<ApiVariant[]>;
    getVariants(companyId: ObjectId, skus: string[]): Promise<ApiVariant[]>;
    requestShallowPricingReport(companyId: ObjectId, marketplace: MarketplaceName, credentials: IMwsCredentials): Promise<any>;
    deleteProducts(companyId: ObjectId, skus: string[]): Promise<any>;
}
export interface ApiPrice {
    base: number;
    selling?: number;
    min?: number;
    max?: number;
}
export interface ApiAsins extends Dict<string, AmazonType> {
}
export interface ApiVariant {
    companyId: ObjectId;
    sku: string;
    barcode: ApiBarcode;
    image?: string;
    name: string;
    stock: number;
    prices: Dict<ApiPrice, MarketplaceName>;
    removedAt?: Date;
    asins: ApiAsins;
    shippingTemplate?: string;
    locks?: string[];
    updatedAt?: Date;
    /**
     * Parent product info
     */
    parent?: string;
}
